@@ -3,7 +3,6 @@ import copy, logging
 
 from webassets import Environment as AssetsEnvironment
 
-from optimus.builder.bundles import COMMON_BUNDLES
 from optimus.conf import settings
 
 class AssetRegistry(object):
@@ -46,13 +45,12 @@ def register_assets():
     """
     logger = logging.getLogger('optimus')
     if not settings.ENABLED_BUNDLES:
-        logger.info("Asset registering skipped as there are no enabled bundles")
+        logger.warning("Asset registering skipped as there are no enabled bundles")
         return None
     logger.info("Starting asset registering")
     
     # Assets bundles
-    AVAILABLE_BUNDLES = copy.deepcopy(COMMON_BUNDLES)
-    AVAILABLE_BUNDLES.update(getattr(settings, 'EXTRA_BUNDLES', {}))
+    AVAILABLE_BUNDLES = getattr(settings, 'BUNDLES', {})
     
     # Initialize webassets environment
     assets_env = AssetsEnvironment()
